@@ -1,29 +1,34 @@
-from expressoptionchain.helper import get_secrets
-from kiteconnect import KiteConnect
 import logging
 
+from kiteconnect import KiteConnect
+
 log = logging.getLogger(__name__)
 
+
 class KiteConnectionManager:
     __kite_client = None
 
-    def __init__(self, api_key, access_token):
+    def __init__(self, secrets):
         log.info('Creating kite client')
-        secrets = get_secrets()
         kite_client = KiteConnect(api_key=secrets['api_key'])
         kite_client.set_access_token(secrets['access_token'])
         KiteConnectionManager.__kite_client = kite_client
+        self.secrets = secrets
 
     @staticmethod
-    def get_kite_client(api_key, access_token):
+    def get_kite_client(secrets):
         if not KiteConnectionManager.__kite_client:
-            KiteConnectionManager(api_key, access_token)
+            KiteConnectionManager(secrets)
         return KiteConnectionManager.__kite_client
 
+    @staticmethod
+    def check_connection():
+        KiteConnectionManager.__kite_client.profile()
+
 
 class KiteConnector:
-    def __init__(self, api_key: str, access_token: str) -> None:
-        self.kite_client = KiteConnectionManager.get_kite_client(api_key, access_token)
+    def __init__(self, secrets: dict) -> None:
+        self.kite_client = KiteConnectionManager.get_kite_client(secrets)
 
     def get_ltp(self, trading_symbols: list[str]) -> dict[str, dict[str, float]]:
         '''
