@@ -1,12 +1,8 @@
 import redis
 
 
-def get_redis_config(db=0):
-    return {'db': 0}
-
-
 class RedisConfig:
-    def __init__(self, port=6739, db=0):
+    def __init__(self, port=6379, db=0):
         self.db = db
         self.port = port
 
@@ -17,4 +13,4 @@ def get_redis_instance(redis_config: RedisConfig = RedisConfig()):
         r.ping()
     except:
         raise Exception(f'Redis is not running port {redis_config.port} ')
-
+    return r
